K.LR: K-separate linear regression models

Description Usage Arguments Details Value See Also

Description

K.LR is a function for fitting a system of K separate linear regression models, one for each treatment group, for estimating the treatment-by-covariates interaction effects.

Usage

1
K.LR(y, Tr, X, use.lasso = TRUE)

Arguments

y

treatment outcomes, n-by-1 vector

Tr

treatment indicators, n-by-1 vector; each element represents one of the K available treatment options

X

a pretreatment covarate matrix, n-by-p matrix

use.lasso

if TRUE, estimate the treatment-specific linear regression coefficients via the Lasso, with the tuning paramters selected by n.folds cross-validation for prediction errors.

Details

A common way to model the treatment-by-covariates interaction effects is to use a system of separate regression functions; one for each level of the treatment variable. For example, one can fit a linear regression model for treatment outcomes, for each treatment group separately. One popular apporoach is to use the Lasso for estimating the regression coefficients, which is implented here.

Value

a list of information of the K separately fitted linear models.

See Also

pred.K.LR


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.