K.SAM: K-separate sparse additive models

Description Usage Arguments Details Value See Also

Description

K.SAM is a function for fitting a system of K separate (sparse) additve models (Ravikumar et al. 2009), one for each treatment group, for estimating the treatment-by-covariates (possibly nonlinear) interaction effects.

Usage

1
K.SAM(y, Tr, X, lambda.opt = NULL, n.folds = 5)

Arguments

y

treatment outcomes, n-by-1 vector

Tr

treatment indicators, n-by-1 vector; each element represents one of the K available treatment options

X

a pretreatment covarate matrix, n-by-p matrix

lambda.opt

the sparsity tuning paramters, to be selected by n.folds cross-validation for prediction errors, if lambda.opt=NULL; the default is NULL.

n.folds

an integer value specifying the number of folds to be used in cross-validation.

Details

A common way to model the treatment-by-covariates interaction effects is to use a system of separate regression functions; one for each level of the treatment variable. For example, one can fit a regression model for treatment outcomes, for each treatment group separately. One popular apporoach is to use a sparse additive model for fitting the regression fuunctions, which is implented here.

Value

a list of information of the K separately fitted sparse additive models.

See Also

pred.K.SAM


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.