block.cd: A block coordinate descent function

Description Usage Arguments Value See Also

Description

block.cd implements the block-coordinate descent algorithm of Radchenko (2015) to optimize the (active) single index coefficients.

Usage

1
2
3
block.cd(w.a, ind.m, ind.old, u, y, Tr, X.a, d.link.fn.obj, it.max = 60,
  eps = 10^-4, trace = F, nbasis.t = c(6, 6, 8), rho.grid = c(0,
  0.25, 0.5), linear.link = FALSE, ortho.constr = TRUE)

Arguments

w.a

a warm start (initial) value of the current nonzero single index coefficients.

ind.m

a value of the index used in defining each coordinate-wise block.

ind.old

a vector of the indices corresponding to the current nonzero coefficients.

u

a vector of the current singe index variable, u = alpha'X.

y

treatment outcomes, a n-by-1 vector.

Tr

treatment indicators, a n-by-1 vector; each element represents one of the K available treatment options.

X.a

a matrix of the pre-treatment covarates, associated with the current nonzero single index coefficients.

d.link.fn.obj

an object of the class d.link.fn.obj passed from the previous iteration.

it.max

an integer value specifying the maximum number of iterations for each coordinate.

eps

a value specifying the converge criterion of algorithm.

trace

if TRUE, show the trace of the fitting procedure; the default is FALSE.

nbasis.t

a length K+1 vector; each element specifies the number of B-spline basis funtions for approximating the treatment-specific link function; the last element is for the "main effect" link function; the default is nbasis.t=NULL, and will be determined depending on the sample size.

rho.grid

a grid vector of (ridge-type) smoothing parameters for approximating the link functions.

linear.link

if TRUE, restrict the link functions to be linear functions; the default is FALSE.

ortho.constr

the constraint that separates the interaction effects from the main effect (without this, the interaction effect can be confounded by the main effect); the default is TRUE.

Value

a list of information of the optimized single index coefficients including

w.a

a vector of the optimized single index coefficients associated with the active index set.

u

a vector of the optimized single index variable.

it

the number of iterations.

See Also

pred.csim, fit.csim, fit.csim.cv


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.