deriv.link.fn: A first derivative of the link functions estimator

Description Usage Arguments Value See Also

Description

A subfunction to compute the first derivative of the link functions, evaluated at the current single index variable u = alpha'X.

Usage

1
2
## S3 method for class 'link.fn'
deriv(link.fn.obj)

Arguments

link.fn.obj

a fitted link function object of class link.fn, obtained from the functions fit.link.fn or fit.link.fn.gcv.

Value

a list of information of the fitted link functions given the current single index variable including

d.link.fn

a n x 1 vector of the 1st derivatives of the estimated link functions evaluated at the current index u = alpha'X.

d.link.fn1

an associated n x 1 vector used in computing the gradient with respect to the single index coefficients.

d.link.fn2

an associated n x 1 vector used in computing the updating rule for the single index coefficients.

See Also

fit.link.fn, fit.link.fn.gcv, fit.csim, block.cd


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.