fit.csim: A Constrained single index model (workhorse function)

Description Usage Arguments Details Value Author(s) See Also

Description

fit.csim is the workhorse function for fitting CSIM. CSIM uses pre-treatment covariates X for modeling the treatment-specific scalar-valued treatment outcomes y. The single index variable is defined to be a linear combinations of X. The differnetial treatment effect is estimated by treatment-specific nonparametrically-defined link functions on the single index variable. For simultaneous covariate selection for the treatment effect modifiers, fit.csim returns a matrix of sparse single index coefficient vectors obtained via a L1 regularization.

Usage

1
2
3
4
5
fit.csim(y, Tr, X, ortho.constr = TRUE, sparse = TRUE, type = "BIC",
  lam.by = 0.03, n.lam = 100, n.max = 10, eps = 10^-4,
  it.max = 50, trace = F, nbasis.t = NULL, rho.grid = c(0, 0.25,
  0.5), eff.aug = FALSE, X.aug = NULL, linear.link = FALSE,
  coef.ini = NULL, i.fx = NULL, mc.ini = FALSE, unit.norm = FALSE)

Arguments

y

treatment outcomes, n-by-1 vector

Tr

treatment indicators, n-by-1 vector; each element represents one of the K available treatment options

X

pre-treatment covarate matrix, n-by-p matrix

ortho.constr

the constraint that separates the interaction effects from the main effect (without this, the interaction effect can be confounded by the main effect); the default is TRUE.

sparse

if TRUE, apply L1 regularization when estimating the single index coefficients; the default is TRUE.

type

when sparse=TRUE, can choose bewteen "CV" and "BIC", for the sparsity tuninig parameter selection.

lam.by

a value specifying the grid of the sparsity tuning parameters [1, 1+lam.by, ... 1 + n.lam*lam.by].

n.lam

a value specifying the grid of the sparsity tuning parameters [1, 1+lam.by, ... 1 + n.lam*lam.by].

n.max

a maximum number of nonzero (active) coeffients in CSIM.

eps

a value specifying the converge criterion of algorithm.

it.max

an integer value specifying the maximum number of iterations for each coordinate.

trace

if TRUE, show the trace of the fitting procedure; the default is FALSE.

nbasis.t

a length K+1 vector; each element specifies the number of B-spline basis funtions for approximating the treatment-specific link function; the last element is for the "main effect" link function; the default is nbasis.t=NULL, and will be determined depending on the sample size.

rho.grid

a grid vector of (ridge-type) smoothing parameters for approximating the link functions.

eff.aug

if TRUE, perform efficiency augmentation (using a L1 regularized linear regression for the main effects of X); the default is FALSE.

X.aug

a design matrix to be used for efficinecy augmentation; the default is NULL.

linear.link

if TRUE, restrict the link functions to be linear functions; the default is FALSE.

coef.ini

an initial solution for alpha.coef.

i.fx

a value of the index to be fixed throughout the estimation for model identifiability; the default is NULL, hence it is estimated.

mc.ini

if TRUE, use an estimate obtained from the modified covariate method as an initial solution; this is only applicable for K=2 case; the default is FALSE.

unit.norm

if TRUE, set the estimated coefficient vector to have a unit norm for model identifiability; the default is to set the component with the largest magnitude to be 1.

Details

The sequence of the model coefficients implied by the tuning paramters lam is fit by block coordinate descent algorithm.

Value

a list of information of the fitted models including

coef

a matrix of the estimated single index coefficients, in which each row corresponds to the coefficients given each value of the tuning parameters lam.

coef.pst

a matrix of the re-fitted single index coefficients, in which each row corresponds to each value of the tuning parameters lam; the single index coefficients is re-fitted without regularization given a set of selected covariates implied by the nonzero components of coef, and store in coef.pst.

eta.coef

the estimated main effect coefficients if eff.aug=TRUE.

intercept.y

a list of the treatment-specific intercepts of the model

center.X

a vector whose elements are the means of the pretreatment covariates.

scale.X

a vector whose elements are the standard deviations of the pretreatment covariates.

Author(s)

Park, Petkova, Tarpey, Ogden

See Also

csim, fit.csim.cv, pred.csim


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.