fit.csim.cv: A Constrained single index model (a wrapper function for...

Description Usage Arguments Value Author(s) See Also

Description

fit.csim.cv performs a 5 fold cross validation to choose the sparsity tuning parameter, and returns the model with the optimized tuning parameter. If type="AIC", then the function returns the model with the lowest value of AIC.

Usage

1
2
3
4
5
6
fit.csim.cv(y, Tr, X, ortho.constr = TRUE, sparse = TRUE,
  type = "AIC", seed = 1234, lam.by = 0.03, n.lam = 100,
  n.max = 10, eps = 10^-4, it.max = 50, trace = F,
  nbasis.t = NULL, rho.grid = c(0, 0.25, 0.5), eff.aug = FALSE,
  X.aug = NULL, linear.link = FALSE, coef.ini = NULL, i.fx = NULL,
  mc.ini = FALSE, unit.norm = FALSE)

Arguments

y

treatment outcomes, n-by-1 vector

Tr

treatment indicators, n-by-1 vector; each element represents one of the K available treatment options

X

a pretreatment covarate matrix, n-by-p matrix

ortho.constr

the constraint that separates the interaction effects from the main effect (without this, the interaction effect can be confounded by the main effect); the default is TRUE.

sparse

if TRUE, apply L1 regularization when estimating the single index coefficients; the default is TRUE.

type

when sparse=TRUE, can choose bewteen "CV" and "BIC", for the sparsity tuninig parameter selection.

seed

when type="CV", randomization seed for cross validation.

lam.by

a value specifying the grid of the sparsity tuning parameters [1, 1+lam.by, ... 1 + n.lam*lam.by].

n.lam

a value specifying the grid of the sparsity tuning parameters [1, 1+lam.by, ... 1 + n.lam*lam.by].

n.max

a maximum number of nonzero (active) coeffients in CSIM.

eps

a value specifying the converge criterion of algorithm.

it.max

an integer value specifying the maximum number of iterations for each coordinate.

trace

if TRUE, show the trace of the fitting procedure; the default is FALSE.

nbasis.t

a length K+1 vector; each element specifies the number of B-spline basis funtions for approximating the treatment-specific link function; the last element is for the "main effect" link function; the default is nbasis.t=NULL, and will be determined depending on the sample size.

rho.grid

a grid vector of (ridge-type) smoothing parameters for approximating the link functions.

eff.aug

if TRUE, perform efficiency augmentation (using a L1 regularized linear regression for the main effects of X); the default is FALSE.

X.aug

a design matrix to be used for efficinecy augmentation; the default is NULL.

linear.link

if TRUE, restrict the link functions to be linear functions; the default is FALSE.

coef.ini

an initial solution for alpha.coef.

i.fx

a value of the index to be fixed throughout the estimation for model identifiability; the default is NULL, hence it is estimated.

mc.ini

if TRUE, use an estimate obtained from the modified covariate method as an initial solution; this is only applicable for K=2 case; the default is FALSE.

unit.norm

if TRUE, set the estimated coefficient vector to have a unit norm for model identifiability; the default is to set the component with the largest magnitude to be 1.

Value

a list of information of the fitted model including

coef.obj

the fitted fit.csim object with the optimized tuning parameter.

coef.opt

the estimated single index coefficients, given the optimized value of the tuning parameter lam.

coef.pst.opt

the re-fitted single index coefficients, given the optimized value of the tuning parameter lam; the single index coefficients is re-fitted without regularization given a set of selected covariates implied by the nonzero components of coef, and store in coef.pst.

eta.coef

the estimated main effect coefficients if eff.aug=TRUE.

intercept.y

a list of the treatment-specific intercepts of the fitted model

center.X

a vector whose elements are the means of the pretreatment covariates.

scale.X

a vector whose elements are the standard deviations of the pretreatment covariates.

Author(s)

Park, Petkova, Tarpey, Ogden

See Also

csim, fit.csim, pred.csim


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.