fit.link.fn.gcv: A wrapper function for the link function estimator

Description Usage Arguments Value See Also

Description

This is a wrapper function that fits the (B-spline approximated) link functions, given the current single index u = alpha'X. An optimal smoothing parameter, rho.opt, is chosen by minimizing the generalized cross validation (GCV) for prediction errors.

Usage

1
2
fit.link.fn.gcv(y, Tr, u, nbasis.t = NULL, rho.grid = c(0, 0.25, 0.5),
  linear.link = FALSE, ortho.constr = TRUE, ini = FALSE)

Arguments

y

treatment outcomes, n-by-1 vector.

Tr

treatment indicators, n-by-1 vector; each element represents one of the K available treatment options.

u

a vector of the current singe index variable, u = alpha'X.

nbasis.t

a length K+1 vector; each element specifies the number of B-spline basis funtions for approximating the treatment-specific link function; the last element is for the "main effect" link function; the default is nbasis.t=NULL, and will be determined depending on the sample size.

rho.grid

a grid vector of (ridge-type) smoothing parameters for approximating the link functions.

linear.link

if TRUE, restrict the link functions to be linear funtions; the default is FALSE.

ortho.constr

the constraint that separates the interaction effects from the main effect (without this, the interaction effect can be confounded by the main effect); the default is TRUE.

ini

if TRUE, calculate the MSE using the interaction-effect component only.

Value

beta.t.coef

a vector of the estimated treatment-specific B-spline coefficients vectors.

beta.0.coef

a vector of the estimated B-spline coefficients fitted regardless of the treatment indicators.

smoother

the smoother object obtained from smoother.fn used in fitting the link functions.

resid

a vector of the residuals from the current fitted constrained single index model.

working.resid

a vector of the residuals from the current fitted constrained single index model, which accounts for the fitted main effects implied by beta.0.coef.

Q

the criterion value (a MSE estimate) of the current fitted constrained single index model.

rho.opt

the optimized smoothing parameter used in fitting the link functions.

See Also

smoother.fn, fit.link.fn, fit.csim, block.cd


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.