fit.mc: Modified covariate method with efficiency augmentation...

Description Usage Arguments Value See Also

Description

mc is a function for fitting the modified covariate (linear) model of Tian et al. (2015) to estimate the treatment-by-covariates interactions, with efficiency augmentation. CSIM is a semiparametric generalization of the modified covariate model for modeling possilbly nonlinear interaction effects.

Usage

1
2
fit.mc(y, Tr, X, eff.aug = TRUE, X.aug = NULL, use.lasso = TRUE,
  n.folds = 20)

Arguments

y

treatment outcomes, n-by-1 vector

Tr

treatment indicators, n-by-1 vector; each element represents one of the K available treatment options

X

a pretreatment covarate matrix, n-by-p matrix

eff.aug

if TRUE, perform efficiency augmentation (using a L1 regularized linear regression for the main effects of X); the default is FALSE.

X.aug

a design matrix to be used for efficinecy augmentation; the default is NULL.

use.lasso

if TRUE, estimate the treatment-specific linear regression coefficients via the Lasso, with the tuning paramters selected by n.folds cross-validation for prediction errors; the default is FALSE.

n.folds

an integer value specifying the number of folds to be used in cross-validation.

Value

a list of information of the fitted model including

alpha.coef

a vector of the estimated interaction effect (contrast) coefficients.

eta.coef

a vector of the estimated main effect coefficients if eff.aug=TRUE.

intercept.y

a list of the treatment-specific intercepts of the fitted model

center.X

a vector whose elements are the means of the pretreatment covariates.

scale.X

a vector whose elements are the standard deviations of the pretreatment covariates.

MSE

the mean squared error criterion value.

See Also

pred.mc


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.