forw.cd: A coordinate descent function

Description Usage Arguments Details Value See Also

Description

forw.cd implements an ordinary (not a block-) coordinate descent to opitmize the single index coefficients, given an initial single index variable u = alpha'X.

Usage

1
2
3
forw.cd(w.a, u, y, Tr, X.a, nbasis.t = c(6, 6, 8), rho.grid = c(0,
  0.25, 0.5), it.max = 60, eps = 10^-4, trace = F,
  linear.link = FALSE, ortho.constr = TRUE, i.fx = NULL)

Arguments

w.a

an initial estimate of the single index coefficient vector.

u

a vector of the current singe index variable, u = alpha'X.

y

treatment outcomes, n-by-1 vector.

Tr

treatment indicators, n-by-1 vector; each element represents one of the K available treatment options.

X.a

a matrix of the pre-treatment covarates, associated with the single index coefficients.

nbasis.t

a length K+1 vector; each element specifies the number of B-spline basis funtions used in approximating the treatment-specific link function; the last element is for the "main effect" link function.

rho.grid

a grid vector of (ridge-type) smoothing parameters for approximating the link functions.

it.max

an integer value specifying the maximum number of iterations for each coordinate.

eps

a value specifying the converge criterion of algorithm.

trace

if TRUE, show the trace of the fitting procedure; the default is FALSE.

linear.link

if TRUE, restrict the link functions to be linear functions; the default is FALSE.

ortho.constr

the constraint that separates the interaction effects from the main effect (without this, the interaction effect can be confounded by the main effect); the default is TRUE.

i.fx

a value of the index to be fixed throughout the estimation for model identifiability; the default is NULL, hence it is estimated.

Details

This function can be used to fit an un-regularized constrained single index model. This function is also used in obtaining the "post-selected" (re-fitted) single index coefficients, cfs.pst; see fit.csim and block.cd; see also Radchenko (2015) for the post-selected single index coefficient estimator.

Value

a list of information of the optimized single index coefficients including

w.a

a vector of the estimated single index coefficients.

u

a n x 1 vector of the estimated single index variable.

it

the number of iterations.

See Also

pred.csim, fit.csim, fit.csim.cv


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.