lgem: Linear generated effect modifiers method (main)

Description Usage Arguments Value See Also

Description

lgem is a wrapper function for fitting a generated treatment effect modifiers (GEM) model by the "Numerator" criterion of Petkova et al. (2016). The GEM variable is defined as a linear combination of pretreatment covariates X, optimized under a linear model framework to exhibit a strong (linear) interaction effect with the treatment indicator. CSIM is a semiparametric generalization of the GEM model for modeling possilbly nonlinear interaction effects.

Usage

1
2
lgem(y, Tr, X, use.lasso = FALSE, n.folds = 20, eff.aug = FALSE,
  boot.CI = FALSE, n.boot = 200, plots = TRUE)

Arguments

y

treatment outcomes, a n-by-1 vector

Tr

treatment indicators, a n-by-1 vector; each element represents one of the K available treatment options

X

pretreatment covarates, a n-by-p matrix

use.lasso

if TRUE, estimate the treatment-specific linear regression coefficients via the Lasso, with the tuning parameters selected by n.folds cross-validation for prediction errors; the default is FALSE.

n.folds

an integer value specifying the number of folds to be used in cross-validation.

eff.aug

if TRUE, perform efficiency augmentation (using a L1 regularized linear regression for the main effects of X); the default is FALSE.

boot.CI

if TRUE, return a boot object that can be used to construct bootstrap confidence intervals for the single index coefficients; the default is FALSE.

n.boot

when boot.CI=TRUE, a value specifying the number of bootstrap replications.

plots

if TRUE, produce a plot for the link function estimates and the coefficient estimate.

Value

a list of information of the fitted model including

alpha.coef

a vector of the estimated GEM coefficients.

gamma.list

a list of the treatment-specific slopes

coef.list

a list of the treatment-specific coefficients, i.e., the slope times the GEM coefficients.

link.fn.plot

a plot object for the treatment-specific link functions (slopes).

coef.plot

a plot object for the GEM coefficients.

boot.results

a boot object that can be used to construct bootstrap confidence intervals for the GEM coefficients.

See Also

fit.lgem, pred.lgem


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.