pred.K.LR: 'K.LR' prediction function

Description Usage Arguments Value See Also

Description

pred.K.LR makes predictions from the fitted K separate linear models given a K.LR object and a set of pretreatment covariates. The function returns predicted outcomes for each treatment and treatment selection rules.

Usage

1
pred.K.LR(K.LR.obj, newx)

Arguments

K.LR.obj

a K.LR object

newx

a matrix of new values for the pretreatment covariates at which predictions are to be made.

Value

pred.new

a matrix of predicted values; column represents each treatment.

trt.rule

a vector of suggested treatments

See Also

K.LR


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.