pred.K.SAM: 'K.SAM' prediction function

Description Usage Arguments Value See Also

Description

pred.K.SAM makes predictions from the fitted K separate sparse additive models given a K.SAM object and a set of pretreatment covariates. The function returns predicted outcomes for each treatment and treatment selection rules.

Usage

1
pred.K.SAM(K.SAM.obj, newx)

Arguments

K.SAM.obj

a K.SAM object

newx

a matrix of new values for the pretreatment covariates at which predictions are to be made.

Value

pred.new

a matrix of predicted values; column represents each treatment.

trt.rule

a vector of suggested treatments

See Also

K.SAM


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.