pred.csim: 'csim' prediction function

Description Usage Arguments Value Author(s) See Also

Description

This function makes predictions from the constrained single index model given a csim object and pretreatment covariates. The function returns predicted outcomes for each treatment and treatment selection rules.

Usage

1
pred.csim(csim.obj, newx)

Arguments

csim.obj

a csim object

newx

a matrix of new values for the pretreatment covariates at which predictions are to be made.

Value

pred.new

a matrix of predicted values; column represents each treatment.

trt.rule

a vector of suggested treatments

Author(s)

Park, Petkova, Tarpey, Ogden

See Also

csim,fit.csim, fit.csim.cv


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.