pred.lgem: 'lgem' prediction function

Description Usage Arguments Value See Also

Description

pred.lgem makes predictions from the linear GEM model given a lgem object and a set of pretreatment covariates. The function returns predicted outcomes for each treatment and treatment selection rules.

Usage

1
pred.lgem(lgem.obj, newx)

Arguments

lgem.obj

a lgem object

newx

a matrix of new values for the pretreatment covariates at which predictions are to be made.

Value

pred.new

a matrix of predicted values; column represents each treatment.

trt.rule

a vector of suggested treatments

See Also

lgem,fit.lgem


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.