pred.mc: 'mc' prediction function

Description Usage Arguments Value See Also

Description

pred.mc makes predictions from the modfiied covariate model given a mc object and a set of pretreatment covariates. The function returns predicted outcomes for each treatment and treatment selection rules.

Usage

1
pred.mc(mc.obj, newx)

Arguments

mc.obj

a mc object

newx

a matrix of new values for the pretreatment covariates at which predictions are to be made.

Value

pred.new

a matrix of predicted values; column represents each treatment.

trt.rule

a vector of suggested treatments

See Also

mc


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.