smoother.fn: A smoother constructor function

Description Usage Arguments Details Value See Also

Description

Given both a vector of the current single index variable u = alpha'X and a vector of the treatment indicators Tr, smoother.fn constructs a set of B-spline smoother matrices, used in estimating the treatment-specific link functions (see fit.link.fn).

Usage

1
2
smoother.fn(Tr, u, nbasis.t = c(6, 6, 8), rho.grid = c(0, 0.25, 0.5),
  linear.link = FALSE)

Arguments

Tr

treatment indicators, n-by-1 vector; each element represents one of the K available treatment options.

u

a vector of the current singe index variable, u = alpha'X.

nbasis.t

a length K+1 vector; each element specifies the number of B-spline basis funtions used in approximating the treatment-specific link function; the last element is for the "main effect" link function.

rho.grid

a grid vector of (ridge-type) smoothing parameters for approximating the link functions.

linear.link

if TRUE, restrict the link functions to be linear funtions; the default is FALSE.

Details

The function returns a set of the QR decomposed design matrices (and the knot sequences used in constructing the B-spline design matrices), over the values of the (ridge-type) smoothing parameters, rho.grid. Since the ridge-type smoothing is equivalent to a regular least squares estimation with added observations, some psedo observations are added to the design matrices for the case of the nonzero values of rho.grid.

Value

a list of information of the smoother matrices given the current single index variable including

Bt.qr

the QR decomposed design matrix constructed based on both the single index variable and the treatment indicator.

B0.qr

the QR decomposed design matrix based on the single index variable only.

Bt

the design matrix based on both the single index variable and the treatment indicator.

B0

the design matrix based on the single index variable only.

knots.t

the knot sequences used in constructing the treatment-specific B-spline design matrices.

See Also

fit.link.fn, fit.link.fn.gcv, fit.csim


syhyunpark/csim documentation built on May 31, 2019, 4:56 a.m.