Description Usage Arguments Details Value See Also
K.SAM is a function for fitting a system of K separate (sparse) additve models (Ravikumar et al. 2009), one for each treatment group, for estimating the treatment-by-covariates (possibly nonlinear) interaction effects.
1 |
y |
treatment outcomes, n-by-1 vector |
Tr |
treatment indicators, n-by-1 vector; each element represents one of the K available treatment options |
X |
a pretreatment covarate matrix, n-by-p matrix |
lambda.opt |
the sparsity tuning paramters, to be selected by |
n.folds |
an integer value specifying the number of folds to be used in cross-validation. |
A common way to model the treatment-by-covariates interaction effects is to use a system of separate regression functions; one for each level of the treatment variable. For example, one can fit a regression model for treatment outcomes, for each treatment group separately. One popular apporoach is to use a sparse additive model for fitting the regression fuunctions, which is implented here.
a list of information of the K separately fitted sparse additive models.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.