Description Usage Arguments Value See Also
block.cd implements the block-coordinate descent algorithm of Radchenko (2015) to optimize the (active) single index coefficients.
1 2 3 |
w.a |
a warm start (initial) value of the current nonzero single index coefficients. |
ind.m |
a value of the index used in defining each coordinate-wise block. |
ind.old |
a vector of the indices corresponding to the current nonzero coefficients. |
u |
a vector of the current singe index variable, u = alpha'X. |
y |
treatment outcomes, a n-by-1 vector. |
Tr |
treatment indicators, a n-by-1 vector; each element represents one of the K available treatment options. |
X.a |
a matrix of the pre-treatment covarates, associated with the current nonzero single index coefficients. |
d.link.fn.obj |
an object of the class |
it.max |
an integer value specifying the maximum number of iterations for each coordinate. |
eps |
a value specifying the converge criterion of algorithm. |
trace |
if |
nbasis.t |
a length K+1 vector; each element specifies the number of B-spline basis funtions for approximating the treatment-specific link function; the last element is for the "main effect" link function; the default is |
rho.grid |
a grid vector of (ridge-type) smoothing parameters for approximating the link functions. |
linear.link |
if |
ortho.constr |
the constraint that separates the interaction effects from the main effect (without this, the interaction effect can be confounded by the main effect); the default is |
a list of information of the optimized single index coefficients including
w.a |
a vector of the optimized single index coefficients associated with the active index set. |
u |
a vector of the optimized single index variable. |
it |
the number of iterations. |
pred.csim, fit.csim, fit.csim.cv
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.