Description Usage Arguments Value Author(s) See Also
A pre-processing function that can be used to construct a data frame consist of a set of the observations in the order of the treatment indicators; i.e., (y, Tr, X) with Tr=1 come first, (y, Tr, X) with Tr=2 come second, ..., and (y, Tr, X) with Tr=K come last.
1 | data.preprocess(y = NULL, Tr, Xsc = NULL, X1D = NULL, optTr = NULL)
|
y |
treatment outcomes, a n-by-1 vector |
Tr |
treatment indicators, a n-by-1 vector; each element represents one of the K available treatment options |
Xsc |
pre-treatment covarates, a n-by-p matrix |
X1D |
a list of q number of 1 dimensional functional covariates, in which each of the functional covariates is evalauted on some grid points |
optTr |
a n-by-1 vector; each element represents the optimal treatment option for the given covariate information; only available for simulated data. |
y |
a n-by-1 vector of the re-ordered treatment outcomes |
Tr |
a n-by-1 vector of the re-ordered treatment indicators |
Xsc |
a n-by-p matrix of the re-ordered pretreatment covarate matrix |
X1D |
a list of q number of the re-ordered 1 dimensional functional covariates, in which each of the functional covariates is evalauted on some grid points |
Park, Petkova, Tarpey, Ogden
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.