Description Usage Arguments Value
dataGenerationFn generates an example dataset under a model that contains a main effect component, a treatment-by-covariates interaction effect component, and a random noise component.
1 2 3 |
n |
sample size. |
p |
dimension of the pretreatment covariates. |
w |
controls the nonliarity of the treatment-specific link function that defines the interaction effect component.
|
delta |
controls the intensity of the main effect.
|
true.alpha |
a vector of the true single index coefficients (associated with the interaction effect component); if |
true.eta |
a vector of the true main effect coefficients; if |
sigma |
standard deviation of the random noise term. |
correlationX |
correlation among the pretreatment covariates. |
sigmaX |
standard deviation of the pretreatment covariates. |
sim.seed |
a seed number for random data generation |
obs |
if |
y |
a n x 1 vector of treatment outcomes. |
Tr |
a n x 1 vector of treatment indicators. |
X |
a n x p matrix of pretreatment covariates. |
SNR |
the "signal" (interaction effects) to "nuisance" (main effects + noise) variance ratio (SNR) of the dataset. |
true.alpha |
the true single index coefficients. |
true.eta |
the true main effect coefficients. |
optTr |
a n x 1 vector of treatments indicating the optimal treatment selections. |
value.opt |
the "Value" of the optimal treatment selection rule, |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.