Description Usage Arguments Value See Also
A subfunction to compute the first derivative of the link functions, evaluated at the current single index variable u = alpha'X.
1 2 | ## S3 method for class 'link.fn'
deriv(link.fn.obj)
|
link.fn.obj |
a fitted link function object of class |
a list of information of the fitted link functions given the current single index variable including
d.link.fn |
a n x 1 vector of the 1st derivatives of the estimated link functions evaluated at the current index u = alpha'X. |
d.link.fn1 |
an associated n x 1 vector used in computing the gradient with respect to the single index coefficients. |
d.link.fn2 |
an associated n x 1 vector used in computing the updating rule for the single index coefficients. |
fit.link.fn, fit.link.fn.gcv, fit.csim, block.cd
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.