Description Usage Arguments Value Author(s) See Also
fit.csim.cv performs a 5 fold cross validation to choose the sparsity tuning parameter, and returns the model with the optimized tuning parameter. If type="AIC", then the function returns the model with the lowest value of AIC.
1 2 3 4 5 6 | fit.csim.cv(y, Tr, X, ortho.constr = TRUE, sparse = TRUE,
type = "AIC", seed = 1234, lam.by = 0.03, n.lam = 100,
n.max = 10, eps = 10^-4, it.max = 50, trace = F,
nbasis.t = NULL, rho.grid = c(0, 0.25, 0.5), eff.aug = FALSE,
X.aug = NULL, linear.link = FALSE, coef.ini = NULL, i.fx = NULL,
mc.ini = FALSE, unit.norm = FALSE)
|
y |
treatment outcomes, n-by-1 vector |
Tr |
treatment indicators, n-by-1 vector; each element represents one of the K available treatment options |
X |
a pretreatment covarate matrix, n-by-p matrix |
ortho.constr |
the constraint that separates the interaction effects from the main effect (without this, the interaction effect can be confounded by the main effect); the default is |
sparse |
if |
type |
when |
seed |
when |
lam.by |
a value specifying the grid of the sparsity tuning parameters [1, 1+lam.by, ... 1 + n.lam*lam.by]. |
n.lam |
a value specifying the grid of the sparsity tuning parameters [1, 1+lam.by, ... 1 + n.lam*lam.by]. |
n.max |
a maximum number of nonzero (active) coeffients in CSIM. |
eps |
a value specifying the converge criterion of algorithm. |
it.max |
an integer value specifying the maximum number of iterations for each coordinate. |
trace |
if |
nbasis.t |
a length K+1 vector; each element specifies the number of B-spline basis funtions for approximating the treatment-specific link function; the last element is for the "main effect" link function; the default is |
rho.grid |
a grid vector of (ridge-type) smoothing parameters for approximating the link functions. |
eff.aug |
if |
X.aug |
a design matrix to be used for efficinecy augmentation; the default is |
linear.link |
if |
coef.ini |
an initial solution for alpha.coef. |
i.fx |
a value of the index to be fixed throughout the estimation for model identifiability; the default is |
mc.ini |
if |
unit.norm |
if |
a list of information of the fitted model including
coef.obj |
the fitted |
coef.opt |
the estimated single index coefficients, given the optimized value of the tuning parameter |
coef.pst.opt |
the re-fitted single index coefficients, given the optimized value of the tuning parameter |
eta.coef |
the estimated main effect coefficients if |
intercept.y |
a list of the treatment-specific intercepts of the fitted model |
center.X |
a vector whose elements are the means of the pretreatment covariates. |
scale.X |
a vector whose elements are the standard deviations of the pretreatment covariates. |
Park, Petkova, Tarpey, Ogden
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.