Description Usage Arguments Value See Also
lgem is a function for fitting a generated treatment effect modifiers (GEM) model
by the "Numerator" criterion of Petkova et al. (2016). The GEM variable is defined as a linear combination of pretreatment covariates X, optimized under a linear model framework to exhibit a strong (linear) interaction effect with the treatment indicator.
CSIM is a semiparametric generalization of the GEM model for modeling possilbly nonlinear interaction effects.
1 |
y |
treatment outcomes, a n-by-1 vector |
Tr |
treatment indicators, a n-by-1 vector; each element represents one of the K available treatment options |
X |
pretreatment covarates, a n-by-p matrix |
use.lasso |
if |
eff.aug |
if |
n.folds |
an integer value specifying the number of folds to be used in cross-validation. |
a list of information of the fitted model including
alpha.coef |
a vector of the estimated GEM coefficients. |
gamma.list |
a list of the treatment-specific slopes |
coef.list |
a list of the treatment-specific coefficients, i.e., the slope times the GEM coefficients. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.