Description Usage Arguments Details Value See Also
Given a vector of responses y and a smoother object obtained from smoother.fn, fit.link.fn computes the treatment-specific link functions of the constrained single index model.
1 | fit.link.fn(y, smoother, ortho.constr = TRUE, ini = FALSE)
|
y |
treatment outcomes, n-by-1 vector. |
smoother |
a smoother object obtained from |
ortho.constr |
the constraint that separates the interaction effects from the main effect (without this, the interaction effect can be confounded by the main effect); the default is |
ini |
if |
This is a subfunction that fits the (B-spline approximated) link functions gt, given the current single index u = alpha'X. An optimal smoothing parameter, rho.opt, is chosen by minimizing the generalized cross validation (GCV) for prediction errors.
a list of information of the fitted link functions given the current single index variable including
beta.t.coef |
a vector of the estimated treatment-specific B-spline coefficients vectors. |
beta.0.coef |
a vector of the estimated B-spline coefficients fitted regardless of the treatment indicators. |
smoother |
the |
resid |
a vector of the residuals from the current fitted constrained single index model. |
working.resid |
a vector of the residuals from the current fitted constrained single index model, which accounts for the fitted main effects implied by |
MSE |
the criterion value (a MSE estimate) of the current fitted constrained single index model. |
rho.opt |
the optimized smoothing parameter used in fitting the link functions. |
smoother.fn, fit.link.fn.gcv, fit.csim
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.