Description Usage Arguments Value See Also
This is a wrapper function that fits the (B-spline approximated) link functions, given the current single index u = alpha'X. An optimal smoothing parameter, rho.opt, is chosen by minimizing the generalized cross validation (GCV) for prediction errors.
1 2 |
y |
treatment outcomes, n-by-1 vector. |
Tr |
treatment indicators, n-by-1 vector; each element represents one of the K available treatment options. |
u |
a vector of the current singe index variable, u = alpha'X. |
nbasis.t |
a length K+1 vector; each element specifies the number of B-spline basis funtions for approximating the treatment-specific link function; the last element is for the "main effect" link function; the default is |
rho.grid |
a grid vector of (ridge-type) smoothing parameters for approximating the link functions. |
linear.link |
if |
ortho.constr |
the constraint that separates the interaction effects from the main effect (without this, the interaction effect can be confounded by the main effect); the default is |
ini |
if |
beta.t.coef |
a vector of the estimated treatment-specific B-spline coefficients vectors. |
beta.0.coef |
a vector of the estimated B-spline coefficients fitted regardless of the treatment indicators. |
smoother |
the |
resid |
a vector of the residuals from the current fitted constrained single index model. |
working.resid |
a vector of the residuals from the current fitted constrained single index model, which accounts for the fitted main effects implied by |
Q |
the criterion value (a MSE estimate) of the current fitted constrained single index model. |
rho.opt |
the optimized smoothing parameter used in fitting the link functions. |
smoother.fn, fit.link.fn, fit.csim, block.cd
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.