Description Usage Arguments Value See Also
mc is a function for fitting the modified covariate (linear) model of Tian et al. (2015) to estimate the treatment-by-covariates interactions, with efficiency augmentation. CSIM is a semiparametric generalization of the modified covariate model for modeling possilbly nonlinear interaction effects.
1 2 |
y |
treatment outcomes, n-by-1 vector |
Tr |
treatment indicators, n-by-1 vector; each element represents one of the K available treatment options |
X |
a pretreatment covarate matrix, n-by-p matrix |
eff.aug |
if |
X.aug |
a design matrix to be used for efficinecy augmentation; the default is |
use.lasso |
if |
n.folds |
an integer value specifying the number of folds to be used in cross-validation. |
a list of information of the fitted model including
alpha.coef |
a vector of the estimated interaction effect (contrast) coefficients. |
eta.coef |
a vector of the estimated main effect coefficients if |
intercept.y |
a list of the treatment-specific intercepts of the fitted model |
center.X |
a vector whose elements are the means of the pretreatment covariates. |
scale.X |
a vector whose elements are the standard deviations of the pretreatment covariates. |
MSE |
the mean squared error criterion value. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.