Description Usage Arguments Value See Also
performance_measure assesses the performance of a given treatment selection rule,
in terms of the "Value" of the treatment selection rule and the proportion of correctly made decisions (PCD).
1 | performance_measure(pred.test, y, Tr, value.opt = NULL, optTr = NULL)
|
pred.test |
a n x K matrix of predicted values given from any model; each column represents each treatment (trt 1, trt 2,..., trt K) |
y |
a n x 1 vector of treatment outcomes from a testing set |
Tr |
a n x 1 vector of treatment indicators from a testing set |
value.opt |
the optimal value of treatment selection rules for the testing set (only available for a simulated dataset). |
optTr |
a vector of treatments indicating the optimal treatment selections for the testing set (only available for a simulated dataset). |
a list of information contating the estimatd Value and the proportion of correct decisions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.