Description Usage Arguments Value See Also
pred.K.SAM makes predictions from the fitted K separate sparse additive models
given a K.SAM object and a set of pretreatment covariates.
The function returns predicted outcomes for each treatment and treatment selection rules.
1 | pred.K.SAM(K.SAM.obj, newx)
|
K.SAM.obj |
a |
newx |
a matrix of new values for the pretreatment covariates at which predictions are to be made. |
pred.new |
a matrix of predicted values; column represents each treatment. |
trt.rule |
a vector of suggested treatments |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.