Description Usage Arguments Value Author(s) See Also
This function makes predictions from the constrained single index model
given a csim object and pretreatment covariates.
The function returns predicted outcomes for each treatment and treatment selection rules.
1 | pred.csim(csim.obj, newx)
|
csim.obj |
a |
newx |
a matrix of new values for the pretreatment covariates at which predictions are to be made. |
pred.new |
a matrix of predicted values; column represents each treatment. |
trt.rule |
a vector of suggested treatments |
Park, Petkova, Tarpey, Ogden
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.